summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvasitemlist_imp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvasitemlist_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qcanvasitemlist_imp.cpp44
1 files changed, 22 insertions, 22 deletions
diff --git a/kjsembed/qtbindings/qcanvasitemlist_imp.cpp b/kjsembed/qtbindings/qcanvasitemlist_imp.cpp
index fd87e511..31f027fd 100644
--- a/kjsembed/qtbindings/qcanvasitemlist_imp.cpp
+++ b/kjsembed/qtbindings/qcanvasitemlist_imp.cpp
@@ -23,19 +23,19 @@
*/
namespace KJSEmbed {
-QCanvasItemListImp::QCanvasItemListImp( KJS::ExecState *exec, int mid, bool constructor )
+TTQCanvasItemListImp::TQCanvasItemListImp( KJS::ExecState *exec, int mid, bool constructor )
: JSProxyImp(exec), id(mid), cons(constructor)
{
}
-QCanvasItemListImp::~QCanvasItemListImp()
+TTQCanvasItemListImp::~TQCanvasItemListImp()
{
}
/**
* Adds bindings for static methods and enum constants to the specified Object.
*/
-void QCanvasItemListImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
+void TQCanvasItemListImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
{
JSProxy::MethodTable methods[] = {
@@ -43,11 +43,11 @@ void QCanvasItemListImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &o
};
int idx = 0;
- TQCString lastName;
+ TTQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
- QCanvasItemListImp *meth = new QCanvasItemListImp( exec, methods[idx].id );
+ TQCanvasItemListImp *meth = new TQCanvasItemListImp( exec, methods[idx].id );
object.put( exec , methods[idx].name, KJS::Object(meth) );
lastName = methods[idx].name;
}
@@ -60,7 +60,7 @@ void QCanvasItemListImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &o
/**
* Adds bindings for instance methods to the specified Object.
*/
-void QCanvasItemListImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
+void TQCanvasItemListImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
{
JSProxy::MethodTable methods[] = {
@@ -70,11 +70,11 @@ void QCanvasItemListImp::addBindings( KJS::ExecState *exec, KJS::Object &object
};
int idx = 0;
- TQCString lastName;
+ TTQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
- QCanvasItemListImp *meth = new QCanvasItemListImp( exec, methods[idx].id );
+ TQCanvasItemListImp *meth = new TQCanvasItemListImp( exec, methods[idx].id );
object.put( exec , methods[idx].name, KJS::Object(meth) );
lastName = methods[idx].name;
}
@@ -83,31 +83,31 @@ void QCanvasItemListImp::addBindings( KJS::ExecState *exec, KJS::Object &object
}
/**
* Extract a TQCanvasItemList pointer from an Object.
*/
-TQCanvasItemList *QCanvasItemListImp::toQCanvasItemList( KJS::Object &self )
+TTQCanvasItemList *TQCanvasItemListImp::toTQCanvasItemList( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- TQObject *obj = ob->object();
+ TTQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<TQCanvasItemList *>( obj );
+ return dynamic_cast<TTQCanvasItemList *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "TQCanvasItemList" )
+ if ( op->typeName() != "TTQCanvasItemList" )
return 0;
- return op->toNative<TQCanvasItemList>();
+ return op->toNative<TTQCanvasItemList>();
}
/**
* Select and invoke the correct constructor.
*/
-KJS::Object QCanvasItemListImp::construct( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasItemListImp::construct( KJS::ExecState *exec, const KJS::List &args )
{
switch( id ) {
@@ -115,14 +115,14 @@ KJS::Object QCanvasItemListImp::construct( KJS::ExecState *exec, const KJS::List
break;
}
- TQString msg = i18n("QCanvasItemListCons has no constructor with id '%1'.").arg(id);
+ TTQString msg = i18n("TQCanvasItemListCons has no constructor with id '%1'.").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
-KJS::Value QCanvasItemListImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
+KJS::Value TQCanvasItemListImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
{
- instance = QCanvasItemListImp::toQCanvasItemList( self );
+ instance = TQCanvasItemListImp::toTQCanvasItemList( self );
switch( id ) {
@@ -138,12 +138,12 @@ KJS::Value QCanvasItemListImp::call( KJS::ExecState *exec, KJS::Object &self, co
break;
}
- TQString msg = i18n( "QCanvasItemListImp has no method with id '%1'." ).arg( id );
+ TTQString msg = i18n( "TQCanvasItemListImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
-KJS::Value QCanvasItemListImp::sort_1( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasItemListImp::sort_1( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
instance->sort( );
@@ -151,10 +151,10 @@ KJS::Value QCanvasItemListImp::sort_1( KJS::ExecState *exec, KJS::Object &obj, c
}
-KJS::Value QCanvasItemListImp::drawUnique_2( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasItemListImp::drawUnique_2( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TQPainter arg0; // TODO (hack for qcanvas)
+ TTQPainter arg0; // TODO (hack for qcanvas)
instance->drawUnique(
arg0 );
@@ -83,31 +83,31 @@ void QCanvasItemListImp::addBindings( KJS::ExecState *exec, KJS::Object &object
}
/**
- * Extract a TQCanvasItemList pointer from an Object.
+ * Extract a TTQCanvasItemList pointer from an Object.
*/